@@ -13,7 +13,7 @@ G_BEGIN_DECLS
 #define GDK_WINDOWING_X11
 #undef GDK_WINDOWING_BROADWAY
 #undef GDK_WINDOWING_MACOS
-#undef GDK_WINDOWING_WAYLAND
+#define GDK_WINDOWING_WAYLAND
 #undef GDK_WINDOWING_WIN32
 
 #define GDK_RENDERING_CAIRO
