@@ -17,8 +17,7 @@
  * License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GTK_RECENT_MANAGER_H__
-#define __GTK_RECENT_MANAGER_H__
+#pragma once
 
 #if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
@@ -81,12 +80,6 @@ struct _GtkRecentData
   gboolean is_private;
 };
 
-/**
- * GtkRecentManager:
- *
- * #GtkRecentManager-struct contains only private data
- * and should be accessed using the provided API.
- */
 struct _GtkRecentManager
 {
   /*< private >*/
@@ -98,7 +91,7 @@ struct _GtkRecentManager
 /**
  * GtkRecentManagerClass:
  *
- * #GtkRecentManagerClass contains only private data.
+ * `GtkRecentManagerClass` contains only private data.
  */
 struct _GtkRecentManagerClass
 {
@@ -129,7 +122,7 @@ struct _GtkRecentManagerClass
  *   resources file.
  * @GTK_RECENT_MANAGER_ERROR_UNKNOWN: unspecified error.
  *
- * Error codes for #GtkRecentManager operations
+ * Error codes for `GtkRecentManager` operations
  */
 typedef enum
 {
@@ -145,7 +138,7 @@ typedef enum
 /**
  * GTK_RECENT_MANAGER_ERROR:
  *
- * The #GError domain for #GtkRecentManager errors.
+ * The `GError` domain for `GtkRecentManager` errors.
  */
 #define GTK_RECENT_MANAGER_ERROR	(gtk_recent_manager_error_quark ())
 GDK_AVAILABLE_IN_ALL
@@ -207,19 +200,19 @@ const char *         gtk_recent_info_get_description      (GtkRecentInfo  *info)
 GDK_AVAILABLE_IN_ALL
 const char *         gtk_recent_info_get_mime_type        (GtkRecentInfo  *info);
 GDK_AVAILABLE_IN_ALL
-time_t                gtk_recent_info_get_added            (GtkRecentInfo  *info);
+GDateTime *          gtk_recent_info_get_added            (GtkRecentInfo  *info);
 GDK_AVAILABLE_IN_ALL
-time_t                gtk_recent_info_get_modified         (GtkRecentInfo  *info);
+GDateTime *          gtk_recent_info_get_modified         (GtkRecentInfo  *info);
 GDK_AVAILABLE_IN_ALL
-time_t                gtk_recent_info_get_visited          (GtkRecentInfo  *info);
+GDateTime *          gtk_recent_info_get_visited          (GtkRecentInfo  *info);
 GDK_AVAILABLE_IN_ALL
-gboolean              gtk_recent_info_get_private_hint     (GtkRecentInfo  *info);
+gboolean             gtk_recent_info_get_private_hint     (GtkRecentInfo  *info);
 GDK_AVAILABLE_IN_ALL
-gboolean              gtk_recent_info_get_application_info (GtkRecentInfo  *info,
-							    const char     *app_name,
-							    const char    **app_exec,
-							    guint          *count,
-							    time_t         *time_);
+gboolean             gtk_recent_info_get_application_info (GtkRecentInfo  *info,
+                                                           const char     *app_name,
+                                                           const char    **app_exec,
+                                                           guint          *count,
+                                                           GDateTime     **stamp);
 GDK_AVAILABLE_IN_ALL
 GAppInfo *            gtk_recent_info_create_app_info      (GtkRecentInfo  *info,
                                                             const char     *app_name,
@@ -257,6 +250,8 @@ gboolean              gtk_recent_info_match                (GtkRecentInfo  *info
 /* private */
 void _gtk_recent_manager_sync (void);
 
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(GtkRecentManager, g_object_unref)
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(GtkRecentInfo, gtk_recent_info_unref)
+
 G_END_DECLS
 
-#endif /* __GTK_RECENT_MANAGER_H__ */
