@@ -16,8 +16,7 @@
  *  License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GTK_SHORTCUTS_SECTION_H__
-#define __GTK_SHORTCUTS_SECTION_H__
+#pragma once
 
 #if !defined (__GTK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gtk/gtk.h> can be included directly."
@@ -40,4 +39,3 @@ GType        gtk_shortcuts_section_get_type (void) G_GNUC_CONST;
 
 G_END_DECLS
 
-#endif /* __GTK_SHORTCUTS_SECTION_H__ */
